"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPlutoRole = exports.getAwsCredentialsFromLocal = exports.getAwsCredentialsFromAuthService = void 0;
const os = __importStar(require("os"));
const crypto_1 = require("crypto");
const credential_providers_1 = require("@aws-sdk/credential-providers");
const tools_1 = require("./tools");
const AWS_CREDENTIALS_QUERY_URL = "https://ryo1adp0pe.execute-api.us-east-1.amazonaws.com/dev/query";
async function getAwsCredentialsFromAuthService(userId) {
    const queryUrl = AWS_CREDENTIALS_QUERY_URL + `?userId=${userId}`;
    const response = await fetch(queryUrl);
    if (response.status != 200) {
        throw new Error(`Get credentials failed, ${await response.text()}.`);
    }
    const data = await response.json();
    return {
        accessKeyId: data["AccessKeyId"],
        secretAccessKey: data["SecretAccessKey"],
        sessionToken: data["SessionToken"],
    };
}
exports.getAwsCredentialsFromAuthService = getAwsCredentialsFromAuthService;
async function getAwsCredentialsFromLocal() {
    // Get credentials from envrionment variables.
    const envProvider = (0, credential_providers_1.fromEnv)();
    let identity = await envProvider().catch(() => undefined);
    if (identity != undefined) {
        return {
            accessKeyId: identity.accessKeyId,
            secretAccessKey: identity.secretAccessKey,
            sessionToken: identity.sessionToken,
        };
    }
    // Get credentials from shared INI credentials file.
    // TODO: Currently, the default path to ~/.aws/credentials is being used.
    //   Enable users to specify the path to the shared credentials file.
    const profile = process.env.AWS_PROFILE ?? "default";
    const credsFilepath = `${os.homedir()}/.aws/credentials`;
    const configFilepath = `${os.homedir()}/.aws/config`;
    const iniProvider = (0, credential_providers_1.fromIni)({
        profile: profile,
        filepath: credsFilepath,
        configFilepath: configFilepath,
    });
    identity = await iniProvider().catch(() => undefined);
    if (identity != undefined) {
        return {
            accessKeyId: identity.accessKeyId,
            secretAccessKey: identity.secretAccessKey,
            sessionToken: identity.sessionToken,
        };
    }
    return undefined;
}
exports.getAwsCredentialsFromLocal = getAwsCredentialsFromLocal;
// TODO: move to cli, and add a role name so that users can change thier accounts.
async function createPlutoRole() {
    // Guide users to create PLRole. Open one tab in the browser.
    const userId = (0, crypto_1.randomUUID)();
    const stackId = userId.split("-")[0];
    const url = `https://us-east-1.console.aws.amazon.com/cloudformation/home?region=us-east-1#/stacks/quickcreate?templateURL=https://plutolang.s3.amazonaws.com/roleTemplate.yml&stackName=PLSetup-${stackId}&param_RoleName=PLRole-${stackId}&param_UserId=${userId}`;
    open(url);
    let succ = false;
    const interval = 10;
    for (let i = 0; i < (3 * 60) / interval; i++) {
        await (0, tools_1.sleep)(interval);
        try {
            await getAwsCredentialsFromAuthService(userId);
            succ = true;
            break;
        }
        catch (e) {
            console.log("Waiting for PLRole creation...");
        }
    }
    if (succ) {
        console.log("Successfully created PLRole!");
        return userId;
    }
    else {
        throw new Error("Failed to create PLRole.");
    }
}
exports.createPlutoRole = createPlutoRole;
//# sourceMappingURL=aws-credentials.js.map